@@ -132,8 +132,10 @@ def get_all_gene(trainset_dir):
     dataset_list = os.listdir(trainset_dir)
     gene = []
     for dataset in dataset_list:
-        if '.txt' in dataset or '.csv' in dataset:
+        if '.txt' in dataset:
             df = pd.read_csv(trainset_dir + dataset, sep='\t')
+        elif '.csv' in dataset:
+            df = pd.read_csv(trainset_dir + dataset)
         elif '.h5' in dataset and '_processed' not in dataset:
             df = pd.read_hdf(trainset_dir + dataset)
         else:
@@ -158,8 +160,10 @@ def process_data_to_same_gene(gene, root_dir, output_dir, mode):
     dataset_list = os.listdir(root_dir)
     for l in tqdm(range(len(dataset_list))):
         dataset = dataset_list[l]
-        if '.txt' in dataset or '.csv' in dataset:
+        if '.txt' in dataset:
             all_data = pd.read_csv(root_dir + dataset, sep='\t')
+        elif '.csv' in dataset:
+            all_data = pd.read_csv(root_dir + dataset)
         elif '.h5' in dataset and '_processed' not in dataset:
             all_data = pd.read_hdf(root_dir + dataset)
         else:
